@@ -181,6 +181,9 @@ use Carp qw(croak carp);
 sub initialize {
   my $self = shift;
   $self->SUPER::initialize(@_);
+
+  # We deal with a lot of classes for games, referees, and bots.
+  # Make sure that they all compile!
   if (my $referee_class = $self->referee_class) {
       eval "require $referee_class";
       if ($@) {
@@ -188,12 +191,12 @@ sub initialize {
       }
   }
   if (my $game_class = $self->game_class) {
-      
       eval "require $game_class";
       if ($@) {
 	  die "Failed to require game class $game_class: $@";
       }
   }
+
   $self->{referees} = [];
   $self->startup_time(time);
   $self->{admins} ||= [];
@@ -201,6 +204,18 @@ sub initialize {
   return $self;
 }
 
+# require_bot_configs: Called by volityd as a volidation step.
+# It simply require()s each Bot class, and dies on compilation errors.
+sub require_bot_configs {
+  my $self = shift;
+  for my $bot_config ($self->bot_configs) {
+      eval "require $$bot_config{class}";
+      if ($@) {
+	  die "Failed to require bot class $$bot_config{class}: $@";
+      }
+  }
+}
+
 # This presence handler takes care of auto-approving all subscription
 # requests. Volity servers are very social like that.
 sub jabber_presence {
@@ -472,7 +487,8 @@ sub handle_disco_items_request {
 		node=>$uri,
 		name=>"ruleset information (URI: $uri )",
 	    }));
-	} elsif ( $nodes[0] eq 'open_games' ) {
+	}
+	elsif ( $nodes[0] eq 'open_games' ) {
 	    $self->logger->debug("It's an open_games request.");
 	    # Get a list of referees with open games, and return
 	    # pointers to them.
@@ -487,7 +503,19 @@ sub handle_disco_items_request {
 		    name=>$_->name,
 		}));
 	    } 
-	}     
+	}
+	elsif ( $nodes[0] eq 'bots' ) {
+	    $self->logger->debug("It's a bots request.");
+	    # Get a list of bots, and return pointers to them.
+	    for my $bot_config ($self->bot_configs) {
+		my $item = Volity::Jabber::Disco::Item->new({
+		    jid=>$self->jid,
+		});
+		$item->name($bot_config->{class}->name) if $bot_config->{class}->name;
+		$item->node($bot_config->{class}->algorithm) if $bot_config->{class}->algorithm;
+		push (@items, $item);
+	    }
+	}
     } else {
 	# Just return the two nodes we support.
 	foreach (qw(ruleset open_games)) {
